@@ -25,14 +25,14 @@ tokenize_texts <- function(x, tokens = NULL, type = "word") { # x embeds a chara
         wo[sapply(wo, length) != 0]
       })
     }
-  } else tok <- tokens
+  } else return(tokens)
   tok
 }
 
 compute_sentiment_lexicons <- function(x, tokens, dv, lexicons, how, do.sentence = FALSE, nCore = 1) {
   threads <- min(RcppParallel::defaultNumThreads(), nCore)
   RcppParallel::setThreadOptions(numThreads = threads)
-  if (inherits(x, "character")) x <- quanteda::corpus(x)
+  if (is_only_character(x)) x <- quanteda::corpus(x)
   if (do.sentence == TRUE) {
     tokens <- tokenize_texts(quanteda::texts(x), tokens, type = "sentence")
     valenceType <- ifelse(is.null(lexicons[["valence"]]), 0,
@@ -149,11 +149,9 @@ compute_sentiment_multiple_languages <- function(x, lexicons, languages, feature
 #'
 #' @return If \code{x} is a \code{sento_corpus} object: a \code{sentiment} object, i.e., a \code{data.table} containing
 #' the sentiment scores \code{data.table} with an \code{"id"}, a \code{"date"} and a \code{"word_count"} column,
-#' and all lexicon-feature sentiment scores columns. If \code{do.sentence = TRUE}, an additional
-#' \code{"sentence_id"} column along the \code{"id"} column is added. The tokenized sentences are not
-#' provided but can be obtained as \code{stringi::stri_split_boundaries(texts, type = "sentence")}.
-#' A \code{sentiment} object can be aggregated (into time series) with the \code{\link{aggregate.sentiment}}
-#' function.
+#' and all lexicon-feature sentiment scores columns. The tokenized sentences are not provided but can be
+#' obtained as \code{stringi::stri_split_boundaries(texts, type = "sentence")}. A \code{sentiment} object can
+#' be aggregated (into time series) with the \code{\link{aggregate.sentiment}} function.
 #'
 #' @return If \code{x} is a \pkg{quanteda} \code{\link[quanteda]{corpus}} object: a sentiment scores
 #' \code{data.table} with an \code{"id"} and a \code{"word_count"} column, and all lexicon-feature
@@ -163,6 +161,9 @@ compute_sentiment_multiple_languages <- function(x, lexicons, languages, feature
 #' vector: a sentiment scores \code{data.table} with an auto-created \code{"id"} column, a \code{"word_count"}
 #' column, and all lexicon sentiment scores columns.
 #'
+#' @return When \code{do.sentence = TRUE}, an additional \code{"sentence_id"} column along the
+#' \code{"id"} column is added.
+#'
 #' @examples
 #' data("usnews", package = "sentometrics")
 #' txt <- system.file("texts", "txt", package = "tm")
@@ -211,7 +212,7 @@ compute_sentiment_multiple_languages <- function(x, lexicons, languages, feature
 #' sent8 <- compute_sentiment(corpusSample, l1, how = "proportionalSquareRoot",
 #'                            do.sentence = TRUE)
 #'
-#' # from an artificially constructed multilingual corpus
+#' # from a (fake) multilingual corpus
 #' usnews[["language"]] <- "en" # add language column
 #' usnews$language[1:100] <- "fr"
 #' lEn <- sento_lexicons(list("FEEL_en" = list_lexicons$FEEL_en_tr,
